==> masamune_flutter-0.1.1.tar.gz: lib/component/extensions.dart <==
part of masamune.flutter;

/// BuildContext extension methods
extension BuildContextExtension on BuildContext {
  /// Get object from pathmap in conjunction with UIWidget
  /// You can get any IPath object other than String
  /// Please use it for update processing in the widget
  /// 
  /// [path]: The path to get
  /// [defaultValue]: Value if none
  /// [filter]: Filter values.
  /// [listen]: True to listen for values
  T get<T extends Object>(String path, {T defaultValue, T filter( T value ), bool listen = false}){
    UIValue value = UIValue.of(this);
    if( value == null ) return filter != null ? filter( defaultValue ) : defaultValue;
    return value.get<T>( path, defaultValue: defaultValue, filter:filter, listen: listen );
  }
  /// Get text from pathmap in conjunction with UIWidget
  /// Displays anything as long as Path is Unit and can be converted to text
  /// If not, [defaultValue] will be displayed
  /// 
  /// [path]: The path to get
  /// [defaultValue]: Value if none
  /// [filter]: Filter values.
  /// [listen]: True to listen for values  
  String text(String path, {String defaultValue = Const.empty, String filter( String value ), bool listen = true}){
    UIValue value = UIValue.of(this);
    if( value == null ) return filter != null ? filter( defaultValue ) : defaultValue;
    return value.text( path, defaultValue: defaultValue, filter:filter, listen: listen );
  }
  /// Get localized text from pathmap in conjunction with UIWidget
  /// Displays anything as long as Path is Unit and can be converted to text
  /// If not, [defaultValue] will be displayed
  /// 
  /// [path]: The path to get
  /// [defaultValue]: Value if none
  /// [filter]: Filter values.
  /// [listen]: True to listen for values  
  String localized(String path, {String defaultValue = Const.empty, String filter( String value ), bool listen = true}){
    UIValue value = UIValue.of(this);
    if( value == null ) return filter != null ? filter( Localize.get( defaultValue ) ) : Localize.get( defaultValue );
    return value.localized( path, defaultValue: defaultValue, filter:filter, listen: listen );
  }
  /// Get number from pathmap in conjunction with UIWidget
  /// Displays anything as long as Path is Unit and can be converted to double
  /// If not, [defaultValue] will be displayed
  /// 
  /// [path]: The path to get
  /// [defaultValue]: Value if none
  /// [filter]: Filter values.
  /// [listen]: True to listen for values
  double number(String path, {double defaultValue, double filter( double value ), bool listen = true}){
    UIValue value = UIValue.of(this);
    if( value == null ) return filter != null ? filter( defaultValue ) : defaultValue;
    return value.number( path, defaultValue: defaultValue, filter:filter, listen: listen );
  }
  /// Get the action callback from pathmap in conjunction with UIWidget.
  /// If it does not exist, the action that does nothing is called.
  /// 
  /// [path]: The path to get
  /// [listen]: True to listen for values
  /// [defaultAction]: Default callback when no value exists in path
  Action action( String path, { bool listen = false, Action defaultAction } ){
    UIValue value = UIValue.of(this);
    if( value == null ) return defaultAction ?? (){};
    return value.action( path, listen: listen, defaultAction: defaultAction );
  }
  /// Outputs the theme related to the context
  ThemeData get theme => Theme.of(this);
  /// Get the Navigator related to context
  NavigatorState get navigator => Navigator.of(this);
  /// Get the data passed to the page
  IDataDocument get data => ( ModalRoute.of(this)?.settings?.arguments as IDataDocument ) ?? DataDocument();
}

/// Extension methods of IDataCollection
extension IDataCollectionExtension<TDocument extends IDataDocument> on IDataCollection<TDocument> {
  /// Set the items in the loop
  /// 
  /// [index]: Loop index number
  /// [indexPath]: Index path that can be referenced in the loop
  /// [documentPath]: Document path that can be referenced in the loop
  /// [tapPath]: Tap action path that can be referenced in the loop
  /// [longTapPath]: Long tap action path that can be referenced in the loop
  /// [doubleTapPath]: Double tap action path that can be referenced in the loop
  /// [onTap]: Action when tapped
  /// [onLongTap]: Action when long-tapped
  /// [onDoubleTap]: Action when double-tapped
  void setLoop(
    int index, 
    {
      String indexPath = DefaultPath.loopIndex, 
      String documentPath = DefaultPath.loopItem,
      String tapPath = DefaultPath.loopTap, 
      String longTapPath = DefaultPath.loopTapLong, 
      String doubleTapPath = DefaultPath.loopTapDouble,
      Action onTap,
      Action onLongTap,
      Action onDoubleTap
    }
  ){
    if( isEmpty(indexPath) ) return;
    if( index < 0 || this.length <= index ) return;
    IDataDocument document = this[index];
    if( document == null ) return;
    DataField( indexPath, index );
    if( isNotEmpty(documentPath) ) document.linkTo(documentPath);
    if( onTap != null && isNotEmpty(tapPath) ) DataField( tapPath, onTap );
    if( onLongTap != null && isNotEmpty(longTapPath) ) DataField( longTapPath, onLongTap );
    if( onDoubleTap != null && isNotEmpty(doubleTapPath) ) DataField( doubleTapPath, onDoubleTap );
  }
}

/// Extension methods of IDataDocument
extension IDataDocumentExtension<TField extends IDataField> on IDataDocument<TField> {
  /// Set the items in the loop
  /// 
  /// [index]: Loop index number
  /// [indexPath]: Index path that can be referenced in the loop
  /// [documentPath]: Document path that can be referenced in the loop
  /// [tapPath]: Tap action path that can be referenced in the loop
  /// [longTapPath]: Long tap action path that can be referenced in the loop
  /// [doubleTapPath]: Double tap action path that can be referenced in the loop
  /// [onTap]: Action when tapped
  /// [onLongTap]: Action when long-tapped
  /// [onDoubleTap]: Action when double-tapped
  void setLoop(
    int index, 
    {
      String indexPath = DefaultPath.loopIndex, 
      String documentPath = DefaultPath.loopItem,
      String tapPath = DefaultPath.loopTap, 
      String longTapPath = DefaultPath.loopTapLong, 
      String doubleTapPath = DefaultPath.loopTapDouble,
      Action onTap,
      Action onLongTap,
      Action onDoubleTap
    }
  ){
    if( isEmpty(indexPath) ) return;
    DataField( indexPath, index );
    if( isNotEmpty(documentPath) ) this.linkTo(documentPath);
    if( onTap != null && isNotEmpty(tapPath) ) DataField( tapPath, onTap );
    if( onLongTap != null && isNotEmpty(longTapPath) ) DataField( longTapPath, onLongTap );
    if( onDoubleTap != null && isNotEmpty(doubleTapPath) ) DataField( doubleTapPath, onDoubleTap );
  }

}

==> masamune_flutter-0.1.3.tar.gz: lib/component/extensions.dart <==
part of masamune.flutter;

/// BuildContext extension methods
extension BuildContextExtension on BuildContext {
  /// Get object from pathmap in conjunction with UIWidget
  /// You can get any IPath object other than String
  /// Please use it for update processing in the widget
  /// 
  /// [path]: The path to get
  /// [defaultValue]: Value if none
  /// [filter]: Filter values.
  /// [listen]: True to listen for values
  T get<T extends Object>(String path, {T defaultValue, T filter( T value ), bool listen = false}){
    UIValue value = UIValue.of(this);
    if( value == null ) return filter != null ? filter( defaultValue ) : defaultValue;
    return value.get<T>( path, defaultValue: defaultValue, filter:filter, listen: listen );
  }
  /// Get text from pathmap in conjunction with UIWidget
  /// Displays anything as long as Path is Unit and can be converted to text
  /// If not, [defaultValue] will be displayed
  /// 
  /// [path]: The path to get
  /// [defaultValue]: Value if none
  /// [filter]: Filter values.
  /// [listen]: True to listen for values  
  String text(String path, {String defaultValue = Const.empty, String filter( String value ), bool listen = true}){
    UIValue value = UIValue.of(this);
    if( value == null ) return filter != null ? filter( defaultValue ) : defaultValue;
    return value.text( path, defaultValue: defaultValue, filter:filter, listen: listen );
  }
  /// Get localized text from pathmap in conjunction with UIWidget
  /// Displays anything as long as Path is Unit and can be converted to text
  /// If not, [defaultValue] will be displayed
  /// 
  /// [path]: The path to get
  /// [defaultValue]: Value if none
  /// [filter]: Filter values.
  /// [listen]: True to listen for values  
  String localized(String path, {String defaultValue = Const.empty, String filter( String value ), bool listen = true}){
    UIValue value = UIValue.of(this);
    if( value == null ) return filter != null ? filter( Localize.get( defaultValue ) ) : Localize.get( defaultValue );
    return value.localized( path, defaultValue: defaultValue, filter:filter, listen: listen );
  }
  /// Get number from pathmap in conjunction with UIWidget
  /// Displays anything as long as Path is Unit and can be converted to double
  /// If not, [defaultValue] will be displayed
  /// 
  /// [path]: The path to get
  /// [defaultValue]: Value if none
  /// [filter]: Filter values.
  /// [listen]: True to listen for values
  double number(String path, {double defaultValue, double filter( double value ), bool listen = true}){
    UIValue value = UIValue.of(this);
    if( value == null ) return filter != null ? filter( defaultValue ) : defaultValue;
    return value.number( path, defaultValue: defaultValue, filter:filter, listen: listen );
  }
  /// Get the action callback from pathmap in conjunction with UIWidget.
  /// If it does not exist, the action that does nothing is called.
  /// 
  /// [path]: The path to get
  /// [listen]: True to listen for values
  /// [defaultAction]: Default callback when no value exists in path
  VoidAction action( String path, { bool listen = false, VoidAction defaultAction } ){
    UIValue value = UIValue.of(this);
    if( value == null ) return defaultAction ?? (){};
    return value.action( path, listen: listen, defaultAction: defaultAction );
  }
  /// Outputs the theme related to the context
  ThemeData get theme => Theme.of(this);
  /// Get the Navigator related to context
  NavigatorState get navigator => Navigator.of(this);
  /// Get the data passed to the page
  IDataDocument get data => ( ModalRoute.of(this)?.settings?.arguments as IDataDocument ) ?? DataDocument();
}

/// Extension methods of IDataCollection
extension IDataCollectionExtension<TDocument extends IDataDocument> on IDataCollection<TDocument> {
  /// Set the items in the loop
  /// 
  /// [index]: Loop index number
  /// [indexPath]: Index path that can be referenced in the loop
  /// [documentPath]: Document path that can be referenced in the loop
  /// [tapPath]: Tap action path that can be referenced in the loop
  /// [longTapPath]: Long tap action path that can be referenced in the loop
  /// [doubleTapPath]: Double tap action path that can be referenced in the loop
  /// [onTap]: Action when tapped
  /// [onLongTap]: Action when long-tapped
  /// [onDoubleTap]: Action when double-tapped
  void setLoop(
    int index, 
    {
      String indexPath = DefaultPath.loopIndex, 
      String documentPath = DefaultPath.loopItem,
      String tapPath = DefaultPath.loopTap, 
      String longTapPath = DefaultPath.loopTapLong, 
      String doubleTapPath = DefaultPath.loopTapDouble,
      VoidAction onTap,
      VoidAction onLongTap,
      VoidAction onDoubleTap
    }
  ){
    if( isEmpty(indexPath) ) return;
    if( index < 0 || this.length <= index ) return;
    IDataDocument document = this[index];
    if( document == null ) return;
    DataField( indexPath, index );
    if( isNotEmpty(documentPath) ) document.linkTo(documentPath);
    if( onTap != null && isNotEmpty(tapPath) ) DataField( tapPath, onTap );
    if( onLongTap != null && isNotEmpty(longTapPath) ) DataField( longTapPath, onLongTap );
    if( onDoubleTap != null && isNotEmpty(doubleTapPath) ) DataField( doubleTapPath, onDoubleTap );
  }
}

/// Extension methods of IDataDocument
extension IDataDocumentExtension<TField extends IDataField> on IDataDocument<TField> {
  /// Set the items in the loop
  /// 
  /// [index]: Loop index number
  /// [indexPath]: Index path that can be referenced in the loop
  /// [documentPath]: Document path that can be referenced in the loop
  /// [tapPath]: Tap action path that can be referenced in the loop
  /// [longTapPath]: Long tap action path that can be referenced in the loop
  /// [doubleTapPath]: Double tap action path that can be referenced in the loop
  /// [onTap]: Action when tapped
  /// [onLongTap]: Action when long-tapped
  /// [onDoubleTap]: Action when double-tapped
  void setLoop(
    int index, 
    {
      String indexPath = DefaultPath.loopIndex, 
      String documentPath = DefaultPath.loopItem,
      String tapPath = DefaultPath.loopTap, 
      String longTapPath = DefaultPath.loopTapLong, 
      String doubleTapPath = DefaultPath.loopTapDouble,
      Action onTap,
      Action onLongTap,
      Action onDoubleTap
    }
  ){
    if( isEmpty(indexPath) ) return;
    DataField( indexPath, index );
    if( isNotEmpty(documentPath) ) this.linkTo(documentPath);
    if( onTap != null && isNotEmpty(tapPath) ) DataField( tapPath, onTap );
    if( onLongTap != null && isNotEmpty(longTapPath) ) DataField( longTapPath, onLongTap );
    if( onDoubleTap != null && isNotEmpty(doubleTapPath) ) DataField( doubleTapPath, onDoubleTap );
  }

}
